summaryrefslogtreecommitdiff
path: root/tests/examples/opencv/gstmotioncells_dynamic_test.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/examples/opencv/gstmotioncells_dynamic_test.c')
-rw-r--r--tests/examples/opencv/gstmotioncells_dynamic_test.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/examples/opencv/gstmotioncells_dynamic_test.c b/tests/examples/opencv/gstmotioncells_dynamic_test.c
index 56e359f9c..ad779cc87 100644
--- a/tests/examples/opencv/gstmotioncells_dynamic_test.c
+++ b/tests/examples/opencv/gstmotioncells_dynamic_test.c
@@ -104,7 +104,7 @@ setProperty (GstElement * mcells, char *property, char *prop_value, GType type,
}
}
// gst-launch v4l2src ! videoscale ! videorate ! capsfilter "caps=video/x-raw-yuv,width=320,height=240,framerate=10/1" ! ffmpegcolorspace ! motioncells ! ffmpegcolorspace ! xvimagesink
int
main (int argc, char *argv[])
{
@@ -143,9 +143,9 @@ main (int argc, char *argv[])
decodebin = gst_element_factory_make ("decodebin", "decode");
else
decodebin = NULL;
- colorsp0 = gst_element_factory_make ("ffmpegcolorspace", "colorspace0");
+ colorsp0 = gst_element_factory_make ("videoconvert", "colorspace0");
mcells = gst_element_factory_make ("motioncells", "mcells");
- colorsp1 = gst_element_factory_make ("ffmpegcolorspace", "colorspace1");
+ colorsp1 = gst_element_factory_make ("videoconvert", "colorspace1");
sink = gst_element_factory_make ("xvimagesink", "xv-image-sink");
if (!pipeline || !source || !videor || !videos || !capsf || !colorsp0
|| !mcells || !colorsp1 || !sink) {
@@ -104,7 +104,7 @@ setProperty (GstElement * mcells, char *property, char *prop_value, GType type,
}
}
-// gst-launch v4l2src ! videoscale ! videorate ! capsfilter "caps=video/x-raw-yuv,width=320,height=240,framerate=10/1" ! ffmpegcolorspace ! motioncells ! ffmpegcolorspace ! xvimagesink
+// gst-launch v4l2src ! videoscale ! videorate ! capsfilter "caps=video/x-raw-yuv,width=320,height=240,framerate=10/1" ! videoconvert ! motioncells ! videoconvert ! xvimagesink
int
main (int argc, char *argv[])